@@ -49,7 +49,7 @@ QString SageBackend::id() const
 
 QString SageBackend::version() const
 {
-    return QLatin1String("8.1, 8.2");
+    return QLatin1String("8.3");
 }
 
 Cantor::Session* SageBackend::createSession()
