@@ -55,7 +55,7 @@ class LatexEntry : public WorksheetEntry
 
     void interruptEvaluation() override;
 
-    void layOutForWidth(qreal w, bool force = false) override;
+    void layOutForWidth(qreal w, qreal entry_zone_x, bool force = false) override;
 
     int searchText(const QString& text, const QString& pattern,
                    QTextDocument::FindFlags qt_flags);
